#
# spec file for package ortp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Mariusz Fik <fisiu@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname  libortp
%define sover   13
Name:           ortp
Version:        1.0.2
Release:        5.2
Summary:        Real-time Transport Protocol Stack
License:        GPL-2.0+
Group:          Productivity/Telephony/Utilities
Url:            https://linphone.org/technical-corner/ortp/overview
Source:         https://linphone.org/releases/sources/%{name}/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
# PATCH-FIX-OPENSUSE deps.diff
Patch0:         deps.diff
BuildRequires:  cmake >= 3.0
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bctoolbox) >= 0.6.0

%description
oRTP is a LGPL licensed C library implementing the RTP protocol
(rfc1889).

%package -n %{soname}%{sover}
Summary:        Real-time Transport Protocol Stack
Group:          System/Libraries

%description -n %{soname}%{sover}
oRTP is a LGPL licensed C library implementing the RTP protocol
(rfc1889).

%package devel
Summary:        Headers, libraries and docs for the oRTP library
Group:          Development/Libraries/C and C++
Requires:       %{soname}%{sover} = %{version}
Requires:       cmake
Provides:       %{soname}-devel = %{version}
Obsoletes:      %{soname}-devel < %{version}

%description devel
oRTP is a LGPL licensed C library implementing the RTP protocol
(rfc1889).

This package contains header files and development libraries needed to
develop programs using the oRTP library.

%prep
%setup -q -n %{name}-%{version}-0
%patch0 -p1

%build
%cmake \
  -DENABLE_TESTS=ON   \
  -DENABLE_STATIC=OFF \
  -DENABLE_STRICT=OFF
make %{?_smp_mflags} V=1

%install
%cmake_install

mkdir -p %{buildroot}%{_docdir}/%{name}/
mv -T %{buildroot}%{_datadir}/doc/%{name}-%{version}/ \
  %{buildroot}%{_docdir}/%{name}/

sed -i "s|%{_prefix}/lib|%{_libdir}|g" %{buildroot}%{_libdir}/pkgconfig/%{name}.pc

%post -n %{soname}%{sover} -p /sbin/ldconfig

%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files
%doc %{_docdir}/%{name}/
%{_bindir}/mrtprecv
%{_bindir}/mrtpsend
%{_bindir}/rtprecv
%{_bindir}/rtpsend
%{_bindir}/rtpsend_stupid
%{_bindir}/test_timer
%{_bindir}/tevrtprecv
%{_bindir}/tevrtpsend

%files -n %{soname}%{sover}
%{_libdir}/%{soname}.so.%{sover}*

%files devel
%{_includedir}/%{name}/
%{_libdir}/%{soname}.so
%{_datadir}/oRTP/
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu Jul 20 2017 sor.alexei@meowr.ru
- Update to version 1.0.2:
  * Bug fixes.
- Enable documentation installation.
* Wed Jul  5 2017 jengelh@inai.de
- Add deps.diff to fix the build of ortp users such as libosmo-abis.
* Sun Jun  4 2017 sor.alexei@meowr.ru
- Disable -Werror.
* Wed May 17 2017 sor.alexei@meowr.ru
- Update to version 1.0.1 (changes since 0.27.0):
  * oRTP licence is changed to be GPLv2+.
  * Add a new adaptive jitter buffer algorithm.
  * Minor enhancements and bugfixes.
* Tue Aug 16 2016 mpluskal@suse.com
- Update to version 0.27.0:
  * bctoolbox added as dependency
- Update download url (use github)
- Enable tests
- Switch to cmake build
* Sun Jan 24 2016 jengelh@inai.de
- Add tarball signature
* Fri Nov  6 2015 sor.alexei@meowr.ru
- Update to 0.25.0:
  * Support AVPF generic NACK.
  * Add payload types for RTT (Real-Time Text) and Codec2.
  * Bug fixes.
* Sat Aug 22 2015 tbechtold@suse.com
- update to 0.24.2:
  * Minor release v0.24.2
  * fix typo in rtcp_common_header_get padbit() macro definition
  * Add option to enable/disable documentation generation when building with CMake.
  * set correct dependency
  * configure.ac: add --disable-documentation option to speed up dev builds
  * re-add Requires field for devel rpm
  * AVPF TMMBR/TMMBN: set correct ssrc to handle TMMBR in one-way video calls
  * Release 0.24.1
  * devel package does not require explicit dependency
  * also add epoch to devel rpm
  * set rpm epoc to 1 to be alined with redhat rpm
  * logging.c: split line into 3
  * Fix redefinition of WINAPI_FAMILY_PARTITION when using MinGW64 (thanks to Henrik Pauli for pointing this).
  * increased the size of OrtpEventData.zrtp_sas.sas from 5 to 32 bytes to accomodate the B256 format SAS string
  * add rtp_session_get_symmetric_rtp
  * Define the "Additional #using Directories" when building winrttimer.cpp for Windows Phone.
  * improve logging
  * Fix last commit + allow use of C++.
  * Begin handling of build for Windows Phone with CMake.
  * Do not use absolute path in install instruction of CMake.
  * Fix crash with RTPFB and PSFB packets scheduling.
  * avoid uninstall to fail if nothing was installed before
  * Add support for TMMBR and TMMBN feedback messages (part of RFC 5104).
  * Fix possible receive bandwidth computation imprecision.
* Wed Jul 29 2015 dimstar@opensuse.org
- Add baselibs.conf: build libortp9-32bit, as needed by
  libmediastreamer_base4.
* Sun Mar 15 2015 sor.alexei@meowr.ru
- Update to 0.24.0:
  * RTCP send algorithm as describe in RFC3550.
  * RTCP XR (RFC3611).
  * RTCP send algorithm as describe in RFC4585: AVPF streams.
* Sun May 25 2014 fisiu@opensuse.org
- Update to 0.23.0:
  * network simulator improvements
  * updated to use ZRTPCPP>=4.0
  * security bugfixes
* Wed Jun 26 2013 fisiu@opensuse.org
- ortp-devel obsoletes libortp-devel now.
* Fri Jun 21 2013 fisiu@opensuse.org
- Update to 0.22.0:
  * network simulator improvements for simulating random lost packets
  * srtp initialization bugfix
- Source package renamed to ortp.
* Wed Oct 10 2012 mailaender@opensuse.org
- update to 0.20.0
  - fix an issue on video call with ZRTP
  - ZRTP media encryption
  - SRTP media encryption
  - RTCP support fixes
  - add rtp_session_get_round_trip_propagation()
  - optimisations in session-set intersection computation
  - workaround fix for some versions of uclibc
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Sun Nov  7 2010 pascal.bleser@opensuse.org
- fix Group tags
* Sun Jul 18 2010 dmacvicar@suse.de
- create ortp8 package (0.16.3) from ortp5 (0.13.1)
* Fri Dec 21 2007 crrodriguez@suse.de
- initial package version, required for linphone
